@@ -8,60 +8,62 @@ use parent 'Exporter::Tiny';
 use Class::Usul::Exception;
 use File::DataClass::Constants ( );
 use File::Spec::Functions    qw( tmpdir );
+use IPC::SRLock::Constants     ( );
 
 my $Assert          = sub {};
 my $Config_Extn     = '.json';
 my $Exception_Class = 'Class::Usul::Exception';
+my $Log_Levels      = [ qw( alert debug error fatal info warn ) ];
 
-File::DataClass::Constants->Exception_Class( __PACKAGE__->Exception_Class );
+__PACKAGE__->Exception_Class( $Exception_Class ); # Trigger redispatch
 
 our @EXPORT = qw( ARRAY AS_PARA AS_PASSWORD ASSERT BRK CODE COMMA CONFIG_EXTN
                   DEFAULT_CONFHOME DEFAULT_ENVDIR DEFAULT_ENCODING
                   DEFAULT_L10N_DOMAIN DIGEST_ALGORITHMS ENCODINGS
                   EXCEPTION_CLASS FAILED FALSE HASH LANG LBRACE
-                  LOCALIZE LOG_LEVELS MODE NO NUL OK PERL_EXTNS PHASE
-                  PREFIX QUIT SEP SPC TRUE UNDEFINED_RV
+                  LOCALIZE LOG_LEVELS NO NUL OK PERL_EXTNS PHASE
+                  PREFIX QUIT SEP SPC TRUE UMASK UNDEFINED_RV
                   UNTAINT_CMDLINE UNTAINT_IDENTIFIER UNTAINT_PATH
                   UUID_PATH WIDTH YES );
 
-sub ARRAY    () { q(ARRAY)   }
-sub BRK      () { q(: )      }
-sub CODE     () { q(CODE)    }
-sub COMMA    () { q(,)       }
-sub FAILED   () { 1          }
-sub FALSE    () { 0          }
-sub HASH     () { q(HASH)    }
-sub LANG     () { q(en)      }
-sub LBRACE   () { q({)       }
-sub LOCALIZE () { q([_)      }
-sub MODE     () { q(027)     }
-sub NO       () { q(n)       }
-sub NUL      () { q()        }
-sub OK       () { 0          }
-sub PHASE    () { 2          }
-sub QUIT     () { q(q)       }
-sub SEP      () { q(/)       }
-sub SPC      () { q( )       }
-sub TRUE     () { 1          }
-sub WIDTH    () { 80         }
-sub YES      () { q(y)       }
+sub ARRAY    () { 'ARRAY' }
+sub BRK      () { ': '    }
+sub CODE     () { 'CODE'  }
+sub COMMA    () { ','     }
+sub FAILED   () { 1       }
+sub FALSE    () { 0       }
+sub HASH     () { 'HASH'  }
+sub LANG     () { 'en'    }
+sub LBRACE   () { '{'     }
+sub LOCALIZE () { '[_'    }
+sub NO       () { 'n'     }
+sub NUL      () { q()     }
+sub OK       () { 0       }
+sub PHASE    () { 2       }
+sub QUIT     () { 'q'     }
+sub SEP      () { '/'     }
+sub SPC      () { ' '     }
+sub TRUE     () { 1       }
+sub UMASK    () { '027'   }
+sub WIDTH    () { 80      }
+sub YES      () { 'y'     }
 
 sub AS_PARA             () { { cl => 1, fill => 1, nl => 1 } }
-sub AS_PASSWORD         () { (q(), 1, 0, 0, 1) }
+sub AS_PASSWORD         () { ( q(), 1, 0, 0, 1 ) }
 sub ASSERT              () { __PACKAGE__->Assert }
 sub CONFIG_EXTN         () { __PACKAGE__->Config_Extn }
 sub DEFAULT_CONFHOME    () { tmpdir }
-sub DEFAULT_ENCODING    () { q(UTF-8) }
+sub DEFAULT_ENCODING    () { 'UTF-8' }
 sub DEFAULT_ENVDIR      () { [ q(), qw( etc default ) ] }
-sub DEFAULT_L10N_DOMAIN () { q(default) }
+sub DEFAULT_L10N_DOMAIN () { 'default' }
 sub DIGEST_ALGORITHMS   () { ( qw( SHA-512 SHA-256 SHA-1 MD5 ) ) }
 sub ENCODINGS           () { ( qw( ascii iso-8859-1 UTF-8 guess ) ) }
 sub EXCEPTION_CLASS     () { __PACKAGE__->Exception_Class }
-sub LOG_LEVELS          () { ( qw( alert debug error fatal info warn ) ) }
+sub LOG_LEVELS          () { @{ __PACKAGE__->Log_Levels } }
 sub PERL_EXTNS          () { ( qw( .pl .pm .t ) ) }
-sub PREFIX              () { [ q(), q(opt) ] }
+sub PREFIX              () { [ q(), 'opt' ] }
 sub UNDEFINED_RV        () { -1 }
-sub UNTAINT_CMDLINE     () { qr{ \A ([^\$&;<>|]+)      \z }mx }
+sub UNTAINT_CMDLINE     () { qr{ \A ([^\$&;<>\`|]+)    \z }mx }
 sub UNTAINT_IDENTIFIER  () { qr{ \A ([a-zA-Z0-9_]+)    \z }mx }
 sub UNTAINT_PATH        () { qr{ \A ([^\$%&\*;<>\`|]+) \z }mx }
 sub UUID_PATH           () { [ q(), qw( proc sys kernel random uuid ) ] }
@@ -91,10 +93,20 @@ sub Exception_Class {
       ( "Exception class ${class} is not loaded or has no throw method" );
 
    File::DataClass::Constants->Exception_Class( $class );
+   IPC::SRLock::Constants->Exception_Class( $class );
 
    return $Exception_Class = $class;
 }
 
+sub Log_Levels {
+   my ($self, $levels) = @_; defined $levels or return $Log_Levels;
+
+   ref $levels eq 'ARRAY' and defined $levels->[ 0 ] or EXCEPTION_CLASS->throw
+      ( "Log levels must be an array reference with one defined value" );
+
+   return $Log_Levels = $levels;
+}
+
 1;
 
 __END__
@@ -107,7 +119,7 @@ Class::Usul::Constants - Definitions of constant values
 
 =head1 Synopsis
 
-   use Class::Usul::Constants;
+   use Class::Usul::Constants qw( FALSE SEP TRUE );
 
    my $bool = TRUE; my $slash = SEP;
 
@@ -129,8 +141,14 @@ Defines the following class attributes;
 
 =item C<Exception_Class>
 
+=item C<Log_Levels>
+
 =back
 
+These are accessor / mutators for class attributes of the same name. The
+constants with uppercase names return these values. At compile time they
+can be used to set values the are then constant at runtime
+
 =head1 Subroutines/Methods
 
 =head2 ARRAY
@@ -236,10 +254,6 @@ parameter, C<[_>
 
 List of methods the log object is expected to support
 
-=head2 MODE
-
-Default file creation mask, 027
-
 =head2 NO
 
 The letter C<n>
@@ -281,6 +295,10 @@ Space character
 
 Digit C<1>
 
+=head2 UMASK
+
+Default file creation mask, 027 octal, that's C<rw-r----->
+
 =head2 UNDEFINED_RV
 
 Digit C<-1>. Indicates that a method wrapped in a try/catch block failed
