@@ -4,15 +4,16 @@ use 5.010001;
 use namespace::autoclean;
 
 use Class::Null;
-use Class::Usul::Constants   qw( FALSE LBRACE LOCALIZE NUL SEP TRUE );
+use Class::Usul::Constants   qw( FALSE LANG NUL SEP TRUE );
 use Class::Usul::Functions   qw( assert is_arrayref
                                  is_hashref merge_attributes );
-use Class::Usul::Types       qw( ArrayRef Bool HashRef LogType
-                                 SimpleStr Str Undef );
+use Class::Usul::Types       qw( ArrayRef Bool ConfigType HashRef
+                                 LogType SimpleStr Str );
 use File::DataClass::Types   qw( Directory Path );
 use File::Gettext::Constants qw( CONTEXT_SEP );
 use File::Gettext;
-use File::Spec;
+use File::Gettext::Constants qw( LOCALE_DIRS );
+use File::Spec::Functions    qw( tmpdir );
 use Try::Tiny;
 use Unexpected::Functions    qw( inflate_placeholders );
 use Moo;
@@ -20,15 +21,18 @@ use Moo;
 my $Domain_Cache = {}; my $Locale_Cache = {};
 
 # Public attributes
-has 'l10n_attributes' => is => 'ro',   isa => HashRef, default => sub { {} };
+has 'l10n_attributes' => is => 'lazy', isa => HashRef, builder => sub { {} };
 
-has 'localedir'       => is => 'ro',   isa => Path | Undef, coerce => TRUE;
+has 'locale'          => is => 'lazy', isa => SimpleStr, default => LANG;
+
+has 'localedir'       => is => 'lazy', isa => Path, coerce => TRUE,
+   builder            => sub { LOCALE_DIRS->[ 0 ] };
 
 has 'log'             => is => 'ro',   isa => LogType,
-   default            => sub { Class::Null->new };
+   builder            => sub { Class::Null->new };
 
-has 'tempdir'         => is => 'ro',   isa => Directory, coerce => TRUE,
-   default            => File::Spec->tmpdir;
+has 'tempdir'         => is => 'lazy', isa => Directory, coerce => TRUE,
+   builder            => sub { tmpdir };
 
 # Private attributes
 has '_domains'        => is => 'lazy', isa => ArrayRef[Str], builder => sub {
@@ -115,14 +119,10 @@ around 'BUILDARGS' => sub {
 
    my $builder = delete $attr->{builder} or return $attr;
    my $config  = $builder->can( 'config' ) ? $builder->config : {};
+   my $cfgattr = [ qw( l10n_attributes locale localedir tempdir ) ];
 
    merge_attributes $attr, $builder, {}, [ 'log' ];
-   merge_attributes $attr, $config,  {},
-      [ qw( l10n_attributes localedir tempdir ) ];
-
-   my $names = delete $attr->{domain_names}; # Deprecated
-
-   $attr->{l10n_attributes}->{domains} //= $names;
+   merge_attributes $attr, $config,  {}, $cfgattr;
 
    return $attr;
 };
@@ -141,6 +141,10 @@ sub invalidate_cache {
    $Domain_Cache = {}; return;
 }
 
+sub loc {
+   my $self = shift; return $self->localizer( $self->locale, @_ );
+}
+
 sub localize {
    my ($self, $key, $args) = @_;
 
@@ -149,15 +153,15 @@ sub localize {
    # Lookup the message using the supplied key from the po file
    my $text = $self->$_gettext( $key, $args );
 
-   if (is_arrayref $args->{params}) {
-      0 > index $text, LOCALIZE and return $text;
+   if (defined $args->{params} and ref $args->{params} eq 'ARRAY') {
+      0 > index $text, '[_' and return $text;
 
       # Expand positional parameters of the form [_<n>]
-      return inflate_placeholders [ '[?]', '[]', !$args->{quote_bind_values} ],
+      return inflate_placeholders [ '[?]', '[]', $args->{no_quote_bind_values}],
                                   $text, @{ $args->{params} };
    }
 
-   0 > index $text, LBRACE and return $text;
+   0 > index $text, '{' and return $text;
 
    # Expand named parameters of the form {param_name}
    my %args = %{ $args }; my $re = join '|', map { quotemeta $_ } keys %args;
@@ -172,7 +176,8 @@ sub localizer {
    my $args = (is_hashref $car) ? { %{ $car } }
             : { params => (is_arrayref $car) ? $car : [ @args ] };
 
-   $args->{locale} //= $locale;
+   $args->{locale              } //= $locale;
+   $args->{no_quote_bind_values} //= TRUE;
 
    return $self->localize( $key, $args );
 }
@@ -275,6 +280,12 @@ Returns a hash ref containing the keys and values of the PO header record
 
 Causes a reload of the domain files the next time a message is localised
 
+=head2 loc
+
+   $local_text = $l10n->loc( $key, @args );
+
+Calls L</localizer> supplying L</locale> as the first argument
+
 =head2 localize
 
    $local_text = $l10n->localize( $key, $args );
